#!/bin/bash

#author				: hennes (jm@rapidrabbit.de)
#last changed		: 02-august-2007

#package			: slingshot
#homepage			: http://www.slingshot-game.org
#source location	: http://belnet.dl.sourceforge.net/sourceforge/slingshot-game/slingshot-0.8.1p.tar.gz
#dependencies		: bzip2,cxxlibs,dbus-glib,directfb,expat,fontconfig,freetype,gcc,gdbm,glib2,gtk+2,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,Numeric,openssl,pango,pygame,python,readline,sdl,smpeg,wxgtk,xorg,zlib

# ----- credentials
softname="slingshot"
softversion="0.8.1"
srcurl="http://belnet.dl.sourceforge.net/sourceforge/slingshot-game/slingshot-0.8.1p.tar.gz"
arch="noarch"
cpu=i686
build="1"
zenversion="48"
packageversion="$zenversion.$build"

# ----- verify script
if [ "$(id -u)" != "0" ]; then
			echo "Please run as root!"
			exit 0
fi

# ----- help
if [ "${1}" = "--help" ]; then
	echo \
"$softname ZenBuild

usage:	--help 		Display this text
	--cleanup	Clean up after creating the package
"
	exit 0
fi

# ----- build parameters
numjobs="-j3"
builddir="$(pwd)"
package="$softname-$softversion-$arch-$packageversion"

# ----- prepare directories
dest="$builddir/$package"
rm -rf $dest
prefix="/usr"
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/32x32/apps
mkdir -p $dest/usr/share/icons/hicolor/36x36/apps
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/share/icons/hicolor/64x64/apps
mkdir -p $dest/usr/doc
destsrc="$dest/usr/src/$softname-$softversion"
mkdir -p $destsrc

# ----- make slack-desc-file
cat << EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
slingshot: slingshot (newtonian strategy game)
slingshot:
slingshot: Slingshot is a two dimensional, turn based simulation-strategy game
slingshot: set in the gravity fields of several planets. It is a highly
slingshot: addictive game, and never the same from round to round due to its
slingshot: randomly generated playing fields. The game is deceptively simple.
slingshot: The goal is to shoot the other spacecraft through the field of
slingshot: planets, but their gravity makes it tricky.
slingshot:
slingshot:
slingshot:
EOF

# ----- extract source-archive
srcdir=$softname-$softversion"p"
rm -rf $srcdir
if [ -f $softname-$softversion"p".tar.gz ]; then
   echo "looking for source-file .. found"
else
   echo "looking for source-file .. none found"
   wget -c $srcurl
fi
tar -zxvf $softname-$softversion"p".tar.gz
cd $srcdir

# ----- create package-dependent directories
mkdir -p $dest/usr/doc/$softname-$softversion

# ----- set target-permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 555 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;

# ----- move files
mv ./slingshot/licence.txt $dest/usr/doc/$softname-$softversion
mv ./Readme.txt $dest/usr/doc/$softname-$softversion
mv ./slingshot/* $dest/usr/share/slingshot/

# ----- create executable
cat << EOF > $dest/usr/bin/$softname
#!/bin/bash
cd /usr/share/slingshot
python slingshot.py
EOF

chmod a+x $dest/usr/bin/$softname

# ----- treat icon files
tar -jxvf $builddir/icons.tar.bz2 --directory=$builddir
mv $builddir/icon-slingshot-32.png $dest/usr/share/icons/hicolor/32x32/apps/$softname.png
mv $builddir/icon-slingshot-36.png $dest/usr/share/icons/hicolor/36x36/apps/$softname.png
mv $builddir/icon-slingshot-48.png $dest/usr/share/icons/hicolor/48x48/apps/$softname.png
mv $builddir/icon-slingshot-64.png $dest/usr/share/icons/hicolor/64x64/apps/$softname.png
cp $builddir/icons.tar.bz2 $destsrc

# ----- make .desktop-files
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Slingshot
Comment=A Newtonian strategy game
Comment[de]=Ein Newton'sches Strategie-Spiel
Exec=slingshot
Icon=slingshot
Terminal=false
Type=Application
Categories=Game;Simulation;
Encoding=UTF-8
EOF

# ----- copy build-file
cp "$builddir/build-$softname.sh" "$destsrc/build-$softname.sh"
chmod a+x "$destsrc/build-$softname.sh"

# ----- get-source-script
cat << EOF > "$destsrc/getsrc.sh"
wget -c $srcurl
EOF

chmod a+x "$destsrc/getsrc.sh"

# ----- post-build processing
cd $dest
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | \
	xargs strip --strip-unneeded 2> /dev/null

# ----- packaging
chown -R root.root $dest
cd $dest
makepkg -l y -c n $dest.tgz
cd ..
md5sum $package.tgz > $package.md5
cat << "EOF" > $builddir/$package.dep
bzip2,cxxlibs,dbus-glib,directfb,expat,fontconfig,freetype,gcc,gdbm,glib2,gtk+2,libdrm,libjpeg,libpng,libtiff,mesa,ncurses,Numeric,openssl,pango,pygame,python,readline,sdl,smpeg,wxgtk,xorg,zlib
EOF

# ----- cleaning up
if [ "${1}" = "--cleanup" ]; then
rm -r $dest
rm -r $builddir/$srcdir
fi
